import { useSession } from "next-auth/react";

import { Icons } from "@/components/icons";
import { Button } from "@/components/ui/button";
import { useLike } from "../../hooks/use-like";
import { IGweet } from "../../types";

export const LikeButton = ({ gweet }: { gweet: IGweet }) => {
  const { data: session } = useSession();
  const hasLiked = gweet.likes.some(
    (like) => like.userId === session?.user.id,
  );

  const mutation = useLike({
    gweetAuthorId: gweet.author.id,
    sessionOwnerId: session?.user.id,
  });

  return (
    <div className="inline-flex items-center">
      <Button
        onClick={(e) => {
          e.stopPropagation();
          if (session) {
            mutation.mutate({ gweetId: gweet.id, userId: session.user.id });
          }
        }}
        variant="ghost" size="icon" className="hover:bg-red-800"
      >
        {hasLiked ?
          <Icons.heart className="w-6 h-6 fill-red-600 text-red-600" />
          : <Icons.heart className="w-6 h-6" />
        }
      </Button>

      {gweet.likes.length > 0 && (
        <span className="px-2">{gweet?.likes?.length}</span>
      )}
    </div>
  );
};